@@ -1,7 +1,7 @@
 package Acme::CPANModules::TextTable;
 
 our $DATE = '2020-08-10'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -124,6 +124,18 @@ our $LIST = {
                 box_char => 0,
             },
         },
+        {
+            module => 'Text::Table::Sprintf',
+            bench_code => sub {
+                my ($table) = @_;
+                Text::Table::Sprintf::table(rows=>$table, header_row=>1);
+            },
+            features => {
+                wide_char => 0,
+                color => 0,
+                box_char => 0,
+            },
+        },
         {
             module => 'Text::Table::TinyColor',
             bench_code => sub {
@@ -243,7 +255,7 @@ Acme::CPANModules::TextTable - Modules that generate text tables
 
 =head1 VERSION
 
-This document describes version 0.003 of Acme::CPANModules::TextTable (from Perl distribution Acme-CPANModules-TextTable), released on 2020-08-10.
+This document describes version 0.004 of Acme::CPANModules::TextTable (from Perl distribution Acme-CPANModules-TextTable), released on 2020-08-10.
 
 =head1 SYNOPSIS
 
@@ -273,6 +285,8 @@ L<Text::Table> 1.133
 
 L<Text::Table::Tiny> 1.00
 
+L<Text::Table::Sprintf> 0.001
+
 L<Text::Table::TinyColor> 0.002
 
 L<Text::Table::TinyColorWide> 0.001
@@ -329,6 +343,12 @@ L<Text::Table::Tiny>
 
 
 
+=item * Text::Table::Sprintf (perl_code)
+
+L<Text::Table::Sprintf>
+
+
+
 =item * Text::Table::TinyColor (perl_code)
 
 L<Text::Table::TinyColor>
@@ -406,20 +426,21 @@ Benchmark with default options (C<< bencher --cpanmodules-module TextTable >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
  | participant                   | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
- | Text::ANSITable               |       2.4 |     410   |                 0.00% |              8922.57% |   0.0027  |      20 |
- | Text::ASCIITable              |      11   |      90   |               357.49% |              1872.20% |   0.00027 |      20 |
- | Text::Table::TinyColorWide    |      15   |      65   |               528.50% |              1335.57% |   0.00033 |      20 |
- | Text::FormatTable             |      17   |      58   |               606.85% |              1176.45% |   0.00027 |      20 |
- | Text::Table::TinyWide         |      23   |      44   |               835.18% |               864.80% |   0.00029 |      20 |
- | Text::TabularDisplay          |      42   |      24   |              1628.15% |               422.09% |   0.00011 |      21 |
- | Text::Table::TinyColor        |      60   |      20   |              2201.33% |               292.06% |   0.00021 |      20 |
- | Text::Table::Tiny             |      65.7 |      15.2 |              2591.82% |               235.19% | 1.4e-05   |      20 |
- | Text::Table::HTML::DataTables |      90   |      10   |              3492.19% |               151.17% |   0.00041 |      24 |
- | Text::MarkdownTable           |      90   |      11   |              3602.43% |               143.69% | 4.1e-05   |      21 |
- | Text::Table                   |     110   |       8.9 |              4490.39% |                96.55% | 3.7e-05   |      20 |
- | Text::Table::HTML             |     120   |       8   |              5019.59% |                76.24% | 4.4e-05   |      20 |
- | Text::Table::Org              |     220   |       4.6 |              8863.35% |                 0.66% | 2.7e-05   |      20 |
- | Text::Table::CSV              |     220   |       4.5 |              8922.57% |                 0.00% | 2.1e-05   |      20 |
+ | Text::ANSITable               |       2.6 |     380   |                 0.00% |             16761.03% |   0.0015  |      20 |
+ | Text::ASCIITable              |      11   |      87   |               333.66% |              3788.05% |   0.00039 |      20 |
+ | Text::Table::TinyColorWide    |      16   |      61   |               520.35% |              2617.98% |   0.00024 |      20 |
+ | Text::FormatTable             |      18   |      57   |               567.02% |              2427.81% |   0.00021 |      20 |
+ | Text::Table::TinyWide         |      23   |      43   |               783.26% |              1808.95% |   0.00022 |      20 |
+ | Text::TabularDisplay          |      40   |      20   |              1499.37% |               954.23% |   0.00026 |      20 |
+ | Text::Table::TinyColor        |      61   |      16   |              2204.74% |               631.58% |   0.00012 |      20 |
+ | Text::Table::Tiny             |      67   |      15   |              2451.72% |               560.77% | 3.5e-05   |      21 |
+ | Text::MarkdownTable           |      89   |      11   |              3273.84% |               399.76% | 3.1e-05   |      20 |
+ | Text::Table                   |     110   |       9   |              4102.66% |               301.20% | 4.4e-05   |      20 |
+ | Text::Table::HTML::DataTables |     120   |       8.2 |              4530.68% |               264.12% | 3.9e-05   |      20 |
+ | Text::Table::HTML             |     120   |       8.1 |              4547.02% |               262.84% | 3.8e-05   |      20 |
+ | Text::Table::CSV              |     220   |       4.6 |              8082.09% |               106.07% | 2.2e-05   |      20 |
+ | Text::Table::Org              |     220   |       4.5 |              8294.84% |               100.85% | 3.4e-05   |      20 |
+ | Text::Table::Sprintf          |     450   |       2.2 |             16761.03% |                 0.00% | 1.6e-05   |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
 
  #table2#
@@ -427,20 +448,21 @@ Benchmark with default options (C<< bencher --cpanmodules-module TextTable >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
  | participant                   | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
- | Text::ANSITable               |        23 |    43     |                 0.00% |              7683.96% |   0.0003  |      22 |
- | Text::ASCIITable              |       100 |    10     |               319.69% |              1754.70% |   0.00035 |      20 |
- | Text::Table::TinyColorWide    |       100 |     9     |               402.38% |              1449.43% |   0.00032 |      20 |
- | Text::FormatTable             |       160 |     6.4   |               581.36% |              1042.42% | 3.1e-05   |      20 |
- | Text::Table::TinyWide         |       230 |     4.3   |               910.36% |               670.42% | 3.8e-05   |      21 |
- | Text::TabularDisplay          |       300 |     3     |              1248.66% |               477.16% | 3.3e-05   |      20 |
- | Text::MarkdownTable           |       430 |     2.3   |              1782.02% |               313.60% | 9.4e-06   |      20 |
- | Text::Table                   |       490 |     2.1   |              2016.04% |               267.86% | 1.7e-05   |      20 |
- | Text::Table::Tiny             |       540 |     1.9   |              2242.42% |               232.30% | 1.3e-05   |      20 |
- | Text::Table::TinyColor        |       590 |     1.7   |              2466.37% |               203.31% | 4.8e-06   |      21 |
- | Text::Table::Org              |       990 |     1     |              4183.04% |                81.74% | 7.6e-06   |      20 |
- | Text::Table::HTML::DataTables |      1050 |     0.952 |              4464.93% |                70.52% | 6.9e-07   |      20 |
- | Text::Table::HTML             |      1100 |     0.92  |              4611.97% |                65.20% | 1.4e-06   |      24 |
- | Text::Table::CSV              |      1800 |     0.56  |              7683.96% |                 0.00% | 1.3e-06   |      20 |
+ | Text::ANSITable               |        25 |    40     |                 0.00% |             12440.24% |   0.00015 |      20 |
+ | Text::ASCIITable              |       120 |     8.5   |               364.79% |              2598.03% | 6.2e-05   |      21 |
+ | Text::FormatTable             |       160 |     6.3   |               531.87% |              1884.61% | 1.5e-05   |      20 |
+ | Text::Table::TinyColorWide    |       160 |     6.2   |               541.51% |              1854.80% | 3.5e-05   |      20 |
+ | Text::Table::TinyWide         |       240 |     4.2   |               834.16% |              1242.40% | 1.1e-05   |      20 |
+ | Text::TabularDisplay          |       340 |     3     |              1225.24% |               846.26% | 1.9e-05   |      21 |
+ | Text::MarkdownTable           |       430 |     2.3   |              1584.10% |               644.63% | 1.5e-05   |      20 |
+ | Text::Table                   |       500 |     2     |              1863.78% |               538.58% | 1.1e-05   |      20 |
+ | Text::Table::Tiny             |       590 |     1.7   |              2227.61% |               438.76% | 2.9e-06   |      20 |
+ | Text::Table::TinyColor        |       590 |     1.7   |              2240.66% |               435.76% | 1.3e-05   |      20 |
+ | Text::Table::HTML::DataTables |       970 |     1     |              3725.85% |               227.78% | 7.6e-06   |      20 |
+ | Text::Table::HTML             |      1000 |     0.96  |              4016.61% |               204.63% | 4.5e-06   |      20 |
+ | Text::Table::CSV              |      1800 |     0.57  |              6889.39% |                79.42% | 6.9e-07   |      20 |
+ | Text::Table::Org              |      1800 |     0.556 |              7009.65% |                76.38% | 4.8e-07   |      20 |
+ | Text::Table::Sprintf          |      3200 |     0.32  |             12440.24% |                 0.00% | 6.8e-07   |      21 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+-----------+---------+
 
  #table3#
@@ -448,20 +470,21 @@ Benchmark with default options (C<< bencher --cpanmodules-module TextTable >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Text::ANSITable               |       990 |    1000   |                 0.00% |              7985.60% | 5.9e-06 |      21 |
- | Text::ASCIITable              |      5000 |     200   |               401.08% |              1513.64% | 4.3e-07 |      20 |
- | Text::Table::TinyColor        |      7000 |     100   |               579.59% |              1089.77% |   2e-06 |      20 |
- | Text::FormatTable             |      6900 |     140   |               602.29% |              1051.32% | 2.1e-07 |      20 |
- | Text::Table::TinyColorWide    |      6900 |     140   |               603.04% |              1050.08% | 6.4e-07 |      20 |
- | Text::Table                   |      7600 |     130   |               669.96% |               950.13% | 2.1e-07 |      20 |
- | Text::Table::TinyWide         |     11000 |      90   |              1020.38% |               621.69% | 1.1e-07 |      20 |
- | Text::MarkdownTable           |     13000 |      78   |              1189.69% |               526.94% |   1e-07 |      22 |
- | Text::TabularDisplay          |     13000 |      75   |              1257.03% |               495.83% | 6.5e-07 |      21 |
- | Text::Table::Tiny             |     21000 |      48   |              1993.93% |               286.14% | 5.3e-08 |      20 |
- | Text::Table::HTML::DataTables |     23000 |      43   |              2230.92% |               246.89% | 7.7e-08 |      38 |
- | Text::Table::HTML             |     47500 |      21.1 |              4702.56% |                68.36% |   2e-08 |      20 |
- | Text::Table::Org              |     54000 |      19   |              5357.35% |                48.16% | 5.3e-08 |      20 |
- | Text::Table::CSV              |     80000 |      13   |              7985.60% |                 0.00% | 1.3e-08 |      20 |
+ | Text::ANSITable               |       960 |  1000     |                 0.00% |              9820.22% | 8.7e-06 |      20 |
+ | Text::ASCIITable              |      4900 |   210     |               406.80% |              1857.42% | 9.1e-07 |      20 |
+ | Text::FormatTable             |      6900 |   140     |               617.83% |              1281.97% | 4.8e-07 |      20 |
+ | Text::Table::TinyColorWide    |      7500 |   130     |               682.13% |              1168.37% | 8.5e-07 |      20 |
+ | Text::Table                   |      7700 |   130     |               698.19% |              1142.83% | 1.9e-07 |      24 |
+ | Text::Table::TinyWide         |     11000 |    91     |              1037.74% |               771.93% | 2.1e-07 |      20 |
+ | Text::MarkdownTable           |     12000 |    81     |              1191.67% |               668.02% | 9.4e-08 |      26 |
+ | Text::TabularDisplay          |     15000 |    66     |              1486.35% |               525.35% | 9.5e-08 |      25 |
+ | Text::Table::Tiny             |     21000 |    48     |              2049.30% |               361.55% | 1.1e-07 |      20 |
+ | Text::Table::HTML::DataTables |     23000 |    43     |              2292.39% |               314.66% | 6.7e-08 |      20 |
+ | Text::Table::TinyColor        |     24000 |    41     |              2409.65% |               295.28% | 5.3e-08 |      20 |
+ | Text::Table::HTML             |     47000 |    21     |              4808.67% |               102.10% | 2.7e-08 |      20 |
+ | Text::Table::Org              |     55000 |    18.2   |              5624.03% |                73.31% | 6.7e-09 |      20 |
+ | Text::Table::CSV              |     77523 |    12.899 |              7961.45% |                23.06% | 2.3e-11 |      20 |
+ | Text::Table::Sprintf          |     95000 |    10     |              9820.22% |                 0.00% | 1.3e-08 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table4#
@@ -469,20 +492,21 @@ Benchmark with default options (C<< bencher --cpanmodules-module TextTable >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (μs) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Text::ANSITable               |      3870 |   258     |                 0.00% |              7500.20% | 2.5e-07 |      23 |
- | Text::ASCIITable              |     16000 |    64     |               304.53% |              1778.79% | 2.3e-07 |      22 |
- | Text::Table                   |     21000 |    48     |               437.41% |              1314.22% | 1.6e-07 |      20 |
- | Text::Table::TinyColorWide    |     23000 |    43     |               505.35% |              1155.50% | 5.3e-08 |      20 |
- | Text::MarkdownTable           |     25000 |    39     |               557.65% |              1055.66% | 6.4e-08 |      22 |
- | Text::FormatTable             |     34000 |    29     |               783.38% |               760.36% | 5.2e-08 |      21 |
- | Text::Table::HTML::DataTables |     38000 |    26     |               875.76% |               678.90% | 5.3e-08 |      20 |
- | Text::TabularDisplay          |     50000 |    20     |              1272.94% |               453.57% | 4.5e-07 |      20 |
- | Text::Table::TinyWide         |     58000 |    17     |              1409.51% |               403.49% | 2.7e-08 |      20 |
- | Text::Table::Tiny             |     65037 |    15.376 |              1580.82% |               352.17% | 2.3e-11 |      20 |
- | Text::Table::TinyColor        |     88000 |    11     |              2162.39% |               235.94% | 1.3e-08 |      20 |
- | Text::Table::Org              |    140000 |     7     |              3607.87% |               104.97% | 1.3e-08 |      20 |
- | Text::Table::HTML             |    190000 |     5.27  |              4804.23% |                54.97% | 1.6e-09 |      21 |
- | Text::Table::CSV              |    290000 |     3.4   |              7500.20% |                 0.00% |   5e-09 |      20 |
+ | Text::ANSITable               |      3700 |    270    |                 0.00% |              7771.18% | 1.1e-06 |      20 |
+ | Text::ASCIITable              |     17000 |     58    |               368.96% |              1578.42% | 1.3e-07 |      20 |
+ | Text::Table                   |     20000 |     49    |               453.69% |              1321.57% | 1.6e-07 |      20 |
+ | Text::MarkdownTable           |     25000 |     41    |               565.30% |              1083.10% |   1e-07 |      21 |
+ | Text::FormatTable             |     34000 |     29    |               829.44% |               746.88% | 6.5e-08 |      21 |
+ | Text::Table::HTML::DataTables |     37000 |     27    |               886.46% |               697.92% | 5.1e-08 |      22 |
+ | Text::Table::TinyWide         |     40000 |     20    |              1056.14% |               580.82% | 7.4e-07 |      22 |
+ | Text::Table::TinyColorWide    |     44000 |     23    |              1081.99% |               565.92% | 2.7e-08 |      20 |
+ | Text::TabularDisplay          |     61000 |     16    |              1550.59% |               376.87% | 2.7e-08 |      20 |
+ | Text::Table::Tiny             |     64000 |     16    |              1633.92% |               353.95% | 5.3e-08 |      20 |
+ | Text::Table::TinyColor        |     92600 |     10.8  |              2401.55% |               214.65% | 9.5e-09 |      22 |
+ | Text::Table::Org              |    148000 |      6.75 |              3902.12% |                96.68% | 3.3e-09 |      20 |
+ | Text::Table::HTML             |    185000 |      5.41 |              4892.61% |                57.66% | 1.5e-09 |      25 |
+ | Text::Table::Sprintf          |    280000 |      3.6  |              7417.74% |                 4.70% | 6.4e-09 |      22 |
+ | Text::Table::CSV              |    290000 |      3.4  |              7771.18% |                 0.00% |   5e-09 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
  #table5#
@@ -490,45 +514,47 @@ Benchmark with default options (C<< bencher --cpanmodules-module TextTable >>):
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
  | participant                   | rate (/s) | time (ms) | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors | samples |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
- | Text::ANSITable               |       120 |     8.2   |                 0.00% |              9728.34% | 2.4e-05 |      21 |
- | Text::ASCIITable              |       500 |     2     |               291.25% |              2412.07% | 3.4e-05 |      21 |
- | Text::Table::TinyColorWide    |       600 |     2     |               360.89% |              2032.48% | 6.6e-05 |      20 |
- | Text::FormatTable             |       730 |     1.4   |               495.16% |              1551.37% | 1.5e-06 |      20 |
- | Text::Table::TinyWide         |      1200 |     0.85  |               867.13% |               916.24% | 4.9e-06 |      20 |
- | Text::Table                   |      1200 |     0.84  |               870.97% |               912.22% | 1.3e-06 |      20 |
- | Text::TabularDisplay          |      2200 |     0.46  |              1662.17% |               457.74% | 4.3e-06 |      20 |
- | Text::Table::TinyColor        |      2500 |     0.39  |              1981.23% |               372.24% | 3.1e-06 |      20 |
- | Text::Table::Tiny             |      2900 |     0.34  |              2306.90% |               308.34% | 6.9e-07 |      20 |
- | Text::MarkdownTable           |      3660 |     0.273 |              2898.54% |               227.77% | 2.1e-07 |      20 |
- | Text::Table::Org              |      5400 |     0.19  |              4304.73% |               123.13% | 9.1e-07 |      20 |
- | Text::Table::HTML::DataTables |      5600 |     0.18  |              4507.44% |               113.31% | 4.8e-07 |      20 |
- | Text::Table::HTML             |      6600 |     0.15  |              5295.00% |                82.18% | 2.1e-07 |      20 |
- | Text::Table::CSV              |     12000 |     0.083 |              9728.34% |                 0.00% | 1.3e-07 |      20 |
+ | Text::ANSITable               |       120 |    8.3    |                 0.00% |             11903.43% | 3.2e-05 |      20 |
+ | Text::ASCIITable              |       530 |    1.9    |               336.04% |              2652.85% |   3e-06 |      20 |
+ | Text::FormatTable             |       730 |    1.4    |               504.55% |              1885.52% | 2.9e-06 |      20 |
+ | Text::Table::TinyColorWide    |       870 |    1.2    |               615.28% |              1578.15% | 2.7e-06 |      20 |
+ | Text::Table                   |      1200 |    0.83   |               888.71% |              1114.04% | 1.1e-06 |      20 |
+ | Text::Table::TinyWide         |      1200 |    0.82   |               905.59% |              1093.68% | 3.2e-06 |      20 |
+ | Text::Table::TinyColor        |      1600 |    0.64   |              1180.37% |               837.49% | 4.2e-06 |      20 |
+ | Text::TabularDisplay          |      2310 |    0.432  |              1810.35% |               528.34% | 4.3e-07 |      20 |
+ | Text::Table::Tiny             |      3070 |    0.326  |              2430.80% |               374.29% | 2.1e-07 |      20 |
+ | Text::MarkdownTable           |      3600 |    0.28   |              2859.84% |               305.54% | 6.4e-07 |      20 |
+ | Text::Table::HTML::DataTables |      5660 |    0.177  |              4568.99% |               157.09% | 5.2e-08 |      21 |
+ | Text::Table::HTML             |      6400 |    0.16   |              5220.86% |               125.59% |   2e-07 |      23 |
+ | Text::Table::Org              |      9070 |    0.11   |              7383.21% |                60.40% | 5.3e-08 |      20 |
+ | Text::Table::CSV              |     11900 |    0.0837 |              9756.52% |                21.78% | 2.7e-08 |      20 |
+ | Text::Table::Sprintf          |     15000 |    0.069  |             11903.43% |                 0.00% |   8e-08 |      20 |
  +-------------------------------+-----------+-----------+-----------------------+-----------------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher --cpanmodules-module TextTable --module-startup >>):
 
  #table6#
- +-------------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
- | participant                   | time (ms) | mod_overhead_time | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
- +-------------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
- | Text::ANSITable               |      55   |              46.4 |                 0.00% |               533.41% |   0.00031 |      21 |
- | Text::MarkdownTable           |      45   |              36.4 |                22.56% |               416.82% |   0.00027 |      20 |
- | Text::Table::TinyColorWide    |      34   |              25.4 |                62.31% |               290.25% |   0.00015 |      20 |
- | Text::Table::TinyWide         |      32   |              23.4 |                68.92% |               274.97% |   0.00022 |      20 |
- | Text::Table                   |      30   |              21.4 |               104.38% |               209.92% |   0.00047 |      20 |
- | Text::ASCIITable              |      19   |              10.4 |               180.80% |               125.57% | 9.5e-05   |      20 |
- | Text::Table::Tiny             |      16   |               7.4 |               246.46% |                82.82% | 6.1e-05   |      20 |
- | Text::FormatTable             |      15   |               6.4 |               256.89% |                77.48% | 6.9e-05   |      20 |
- | Text::Table::TinyColor        |      14   |               5.4 |               283.33% |                65.24% | 4.1e-05   |      20 |
- | Text::TabularDisplay          |      11   |               2.4 |               385.83% |                30.38% | 2.9e-05   |      20 |
- | Text::Table::HTML::DataTables |      11   |               2.4 |               414.43% |                23.13% |   5e-05   |      21 |
- | Text::Table::HTML             |      11   |               2.4 |               416.60% |                22.61% | 5.1e-05   |      20 |
- | Text::Table::CSV              |       9.2 |               0.6 |               496.91% |                 6.11% | 5.9e-05   |      20 |
- | Text::Table::Org              |       9   |               0.4 |               506.43% |                 4.45% |   0.00011 |      21 |
- | perl -e1 (baseline)           |       8.6 |               0   |               533.41% |                 0.00% | 7.7e-05   |      20 |
- +-------------------------------+-----------+-------------------+-----------------------+-----------------------+-----------+---------+
+ +-------------------------------+-----------+--------------------+-----------------------+-----------------------+-----------+---------+
+ | participant                   | time (ms) | mod_overhead_time  | pct_faster_vs_slowest | pct_slower_vs_fastest |  errors   | samples |
+ +-------------------------------+-----------+--------------------+-----------------------+-----------------------+-----------+---------+
+ | Text::ANSITable               |     53    | 45                 |                 0.00% |               571.81% |   0.00026 |      20 |
+ | Text::MarkdownTable           |     45    | 37                 |                18.67% |               466.09% |   0.0003  |      20 |
+ | Text::Table::TinyColorWide    |     33    | 25                 |                61.65% |               315.61% | 8.6e-05   |      20 |
+ | Text::Table::TinyWide         |     31    | 23                 |                72.49% |               289.49% |   0.00016 |      20 |
+ | Text::Table                   |     23    | 15                 |               135.78% |               184.93% |   7e-05   |      20 |
+ | Text::ASCIITable              |     18    | 10                 |               199.24% |               124.51% | 5.8e-05   |      20 |
+ | Text::Table::Tiny             |     15    |  7                 |               252.52% |                90.57% | 2.1e-05   |      20 |
+ | Text::FormatTable             |     15    |  7                 |               265.13% |                83.99% | 5.5e-05   |      21 |
+ | Text::Table::TinyColor        |     14    |  6                 |               286.37% |                73.88% | 3.5e-05   |      20 |
+ | Text::TabularDisplay          |     10.6  |  2.6               |               402.33% |                33.74% | 1.1e-05   |      20 |
+ | Text::Table::HTML::DataTables |     10    |  2                 |               410.17% |                31.68% | 6.3e-05   |      20 |
+ | Text::Table::HTML             |      9.85 |  1.85              |               442.91% |                23.74% | 9.2e-06   |      20 |
+ | Text::Table::Sprintf          |      8.5  |  0.5               |               532.31% |                 6.25% | 3.9e-05   |      20 |
+ | Text::Table::CSV              |      8.4  |  0.4               |               539.98% |                 4.97% | 2.2e-05   |      20 |
+ | Text::Table::Org              |      8.2  |  0.199999999999999 |               548.17% |                 3.65% | 1.9e-05   |      21 |
+ | perl -e1 (baseline)           |      8    |  0                 |               571.81% |                 0.00% | 6.7e-05   |      20 |
+ +-------------------------------+-----------+--------------------+-----------------------+-----------------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -544,6 +570,7 @@ To display as an interactive HTML table on a browser, you can add option C<--for
  | Text::MarkdownTable           | no           | no        | no            |
  | Text::Table                   | N/A *4)      | no        | no            |
  | Text::Table::Tiny             | no           | yes       | no            |
+ | Text::Table::Sprintf          | no           | no        | no            |
  | Text::Table::TinyColor        | no           | yes       | no            |
  | Text::Table::TinyColorWide    | no           | yes       | yes           |
  | Text::Table::TinyWide         | no           | no        | yes           |
@@ -589,6 +616,8 @@ Notes:
 
 =item * L<Text::Table::Tiny>
 
+=item * L<Text::Table::Sprintf>
+
 =item * L<Text::Table::TinyColor>
 
 =item * L<Text::Table::TinyColorWide>
